@@ -4,6 +4,7 @@
 
 #include <QCommandLineParser>
 #include <QCoreApplication>
+#include <QtDBus/QDBusMetaType>
 
 #include <KAboutData>
 #include <KCrash>
@@ -13,6 +14,7 @@
 #include "../version.h"
 #include "channellogger.h"
 #include "global.h"
+#include <database.h>
 
 using namespace Qt::Literals;
 
@@ -22,7 +24,8 @@ int main(int argc, char *argv[])
 
     QCoreApplication app(argc, argv);
 
-    KAboutData about(u"Spacebar"_s, u"Spacebar"_s, QStringLiteral(SPACEBAR_VERSION_STRING));
+    // Ensure DBus service is registered as org.kde.spacebar.Daemon
+    KAboutData about(u"spacebar.Daemon"_s, u"Spacebar"_s, QStringLiteral(SPACEBAR_VERSION_STRING));
     KAboutData::setApplicationData(about);
 
     KCrash::initialize();
@@ -31,6 +34,10 @@ int main(int argc, char *argv[])
 
     app.setQuitLockEnabled(false); // prevent a finishing KJob from closing the daemon
 
+    qRegisterMetaType<StringMapList>();
+    qDBusRegisterMetaType<StringMap>();
+    qDBusRegisterMetaType<StringMapList>();
+
     parser.addVersionOption();
     parser.addHelpOption();
     parser.setApplicationDescription(i18n("Spacebar background service"));
